@@ -1,7 +1,10 @@
 import pybullet as p
 import time
 
+import pybullet_data
+
 p.connect(p.GUI)
+p.setAdditionalSearchPath(pybullet_data.getDataPath())
 door = p.loadURDF("door.urdf")
 
 #linear/angular damping for base and all children=0
